==> hprose-3.0.1.tar.gz: lib/src/io/serializers/string_serializer.dart <==
/*--------------------------------------------------------*\
|                                                          |
|                          hprose                          |
|                                                          |
| Official WebSite: https://hprose.com                     |
|                                                          |
| string_serializer.ts                                     |
|                                                          |
| hprose String Serializer for Dart.                       |
|                                                          |
| LastModified: Feb 14, 2019                               |
| Author: Ma Bingyao <andot@hprose.com>                    |
|                                                          |
\*________________________________________________________*/

part of hprose.io;

class StringSerializer extends ReferenceSerializer<String> {
  static final AbstractSerializer<String> instance = new StringSerializer();
  @override
  void write(Writer writer, String value) {
    super.write(writer, value);
    final stream = writer.stream;
    stream.writeByte(TagString);
    ValueWriter.writeStringBody(stream, value);
  }

  @override
  void serialize(Writer writer, String value) {
    final stream = writer.stream;
    switch (value.length) {
      case 0:
        stream.writeByte(TagEmpty);
        break;
      case 1:
        stream.writeByte(TagUTF8Char);
        stream.writeString(value);
        break;
      default:
        super.serialize(writer, value);
        break;
    }
  }
}

==> hprose-3.0.14.tar.gz: lib/src/io/serializers/string_serializer.dart <==
/*--------------------------------------------------------*\
|                                                          |
|                          hprose                          |
|                                                          |
| Official WebSite: https://hprose.com                     |
|                                                          |
| string_serializer.ts                                     |
|                                                          |
| hprose String Serializer for Dart.                       |
|                                                          |
| LastModified: Dec 31, 2019                               |
| Author: Ma Bingyao <andot@hprose.com>                    |
|                                                          |
\*________________________________________________________*/

part of hprose.io;

class StringSerializer extends ReferenceSerializer<String> {
  static final AbstractSerializer<String> instance = StringSerializer();
  @override
  void write(Writer writer, String value) {
    super.write(writer, value);
    final stream = writer.stream;
    stream.writeByte(TagString);
    ValueWriter.writeStringBody(stream, value);
  }

  @override
  void serialize(Writer writer, String value) {
    final stream = writer.stream;
    switch (value.length) {
      case 0:
        stream.writeByte(TagEmpty);
        break;
      case 1:
        stream.writeByte(TagUTF8Char);
        stream.writeString(value);
        break;
      default:
        super.serialize(writer, value);
        break;
    }
  }
}
